@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <qfile.h>
@@ -53,6 +53,7 @@
 #include "marklist.h"
 #include "scrollbox.h"
 #include "version.h"
+#include "configuration.h"
 
 #include <cmath>
 
@@ -141,10 +142,9 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     _pageDecorator = new KGVPageDecorator( _pageView->viewport() );
     _pageDecorator->hide();
 
-    _configDialog = new KGVConfigDialog( _mainWidget, "configdialog" );
 
     _psWidget = new KPSWidget( _pageDecorator );
-    _psWidget->readSettings( _configDialog );
+    _psWidget->readSettings();
     _pageView->setPage( _pageDecorator );
     connect( _psWidget, SIGNAL( output( char*, int ) ),
              this, SLOT( slotGhostscriptOutput( char*, int ) ) );
@@ -156,8 +156,7 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     _logWindow = new LogWindow( i18n( "Ghostscript Messages" ), _mainWidget, "logwindow" );
     _showLogWindow = false;
 
-    connect( _logWindow, SIGNAL( configureGS() ),
-	    _configDialog, SLOT( show() ) );
+    connect( _logWindow, SIGNAL( configureGS() ), SLOT( slotConfigure() ) );
 
     _docManager = new KGVMiniWidget( this );
     _docManager->setPSWidget( _psWidget );
@@ -228,6 +227,10 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     _selectMedia       = new KSelectAction( i18n( "Paper &Size" ), 0, 0, 0,
                                     actionCollection(), "media_menu" );
 
+    _flick = new KToggleAction( i18n( "No &Flicker" ), 0,
+                                this, SLOT( slotFlicker() ),
+                                actionCollection(), "no_flicker" );
+    
     QStringList orientations;
     orientations.append( i18n( "Auto" ) );
     orientations.append( i18n( "Portrait" ) );
@@ -241,11 +244,16 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     connect( _selectMedia, SIGNAL( activated( int ) ),
              this, SLOT( slotMedia( int ) ) );
 
-    _zoomIn  = KStdAction::zoomIn( this,  SLOT( slotZoomIn() ),
-                                   actionCollection(), "zoomIn" );
+    {
+	KShortcut zoomInShort = KStdAccel::zoomIn();
+	zoomInShort.append( KKey( CTRL+Key_Equal ) );
+	_zoomIn = KStdAction::zoomIn( this, SLOT( slotZoomIn() ),
+				    actionCollection(), "zoomIn" );
+	_zoomIn->setShortcut( zoomInShort );
+    }
     _zoomOut = KStdAction::zoomOut( this,  SLOT( slotZoomOut() ),
                                     actionCollection(), "zoomOut" );
-    _zoomTo = new KSelectAction(  i18n( "Zoom" ), "zoomTo", 0, actionCollection(), "zoomTo" );
+    _zoomTo = new KSelectAction(  i18n( "Zoom" ), "viewmag", 0, actionCollection(), "zoomTo" );
     connect(  _zoomTo, SIGNAL(  activated(  const QString & ) ), this, SLOT(  slotZoom( const QString& ) ) );
     _zoomTo->setEditable(  true );
     _zoomTo->clear();
@@ -288,13 +296,13 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
 
     KShortcut readUpShort = KStdAccel::shortcut( KStdAccel::Prior );
     readUpShort.append( KKey( SHIFT+Key_Space ) );
-    _readUp    = new KAction( i18n( "Read Up Document" ), "previous",
+    _readUp    = new KAction( i18n( "Read Up" ), "up",
                               readUpShort, this, SLOT( slotReadUp() ),
                               actionCollection(), "readUp" );
 
     KShortcut readDownShort = KStdAccel::shortcut( KStdAccel::Next );
     readDownShort.append( KKey( Key_Space ) );
-    _readDown  = new KAction( i18n( "Read Down Document" ), "next",
+    _readDown  = new KAction( i18n( "Read Down" ), "down",
                               readDownShort, this, SLOT( slotReadDown() ),
                               actionCollection(), "readDown" );
 
@@ -315,11 +323,6 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
                                 actionCollection(), "show_page_labels" );
     _showPageLabels->setCheckedState(i18n("Hide Page &Labels"));
     KStdAction::preferences( this, SLOT( slotConfigure() ), actionCollection() );
-    /*
-    new KAction( i18n( "&Configure KGhostView..." ), "configure", 0,
-                 this, SLOT( slotConfigure() ),
-		 actionCollection(), "configure" );
-      */
     connect( _showScrollBars, SIGNAL( toggled( bool ) ),
              SLOT( showScrollBars( bool ) ) );
     connect( _showPageList, SIGNAL( toggled( bool ) ),
@@ -430,10 +433,6 @@ bool KGVPart::closeURL()
 void KGVPart::writeSettings()
 {
     KConfigGroup general( KGVFactory::instance()->config(), "General" );
-    general.writeEntry( "ShowScrollBars", _showScrollBars->isChecked() );
-    general.writeEntry( "WatchFile", _watchFile->isChecked() );
-    general.writeEntry( "ShowPageList", _showPageList->isChecked() );
-    general.writeEntry( "ShowPageNames", _showPageLabels->isChecked() );
     if ( !_embeddedInKGhostView )
         general.writeEntry( "Display Options", DisplayOptions::toString( miniWidget()->displayOptions() ) );
     general.sync();
@@ -442,21 +441,26 @@ void KGVPart::writeSettings()
 void KGVPart::readSettings()
 {
     KConfigGroup general( KGVFactory::instance()->config(), "General" );
-    _showScrollBars->setChecked( general.readBoolEntry( "ShowScrollBars", true ) );
+    
+    _showScrollBars->setChecked( Configuration::showScrollBars() );
     showScrollBars( _showScrollBars->isChecked() );
-    _watchFile->setChecked( general.readBoolEntry( "WatchFile", false ) );
+    
+    _watchFile->setChecked( Configuration::watchFile() );
     slotWatchFile();
-    _showPageList->setChecked( general.readBoolEntry( "ShowPageList", true ) );
+    
+    _showPageList->setChecked( Configuration::showPageList() );
     showMarkList( _showPageList->isChecked() );
-    _showPageLabels->setChecked( general.readBoolEntry( "ShowPageNames", false ) );
+    
+    _showPageLabels->setChecked( Configuration::watchFile() );
     showPageLabels( _showPageLabels->isChecked() );
 
-    _showLogWindow = _configDialog->showMessages();
+    _showLogWindow = Configuration::messages();
     if ( !_embeddedInKGhostView ) {
         DisplayOptions options;
         if ( DisplayOptions::fromString( options, general.readEntry( "Display Options" ) ) )
             setDisplayOptions( options );
     }
+    _psWidget->readSettings();
 }
 
 void KGVPart::slotScrollLeft()
@@ -464,6 +468,11 @@ void KGVPart::slotScrollLeft()
     _pageView->scrollLeft();
 }
 
+void KGVPart::slotFlicker()
+{
+    if ( _psWidget ) _psWidget->setDoubleBuffering( _flick->isChecked() );
+}
+
 void KGVPart::slotScrollRight()
 {
     _pageView->scrollRight();
@@ -738,7 +747,7 @@ void KGVPart::slotGhostscriptError( const QString& error )
 				"(<nobr><strong>%2</strong></nobr>) "
 				"which may help you.</qt>" )
 		    .arg( error )
-		    .arg( configDialog()->interpreterPath() ) ,
+		    .arg( Configuration::interpreter() ),
 	   true );
     // The true above makes it show a "configure gs" option, but maybe we
     // should trigger an auto-redetection?
@@ -937,12 +946,14 @@ void KGVPart::reloadFile()
 
 void KGVPart::slotConfigure()
 {
-    _configDialog->setup();
-    if( _configDialog->exec() )
-    {
-	_psWidget->readSettings( _configDialog );
-	miniWidget()->redisplay();
-    }
+    ConfigDialog::showSettings( this );
+}
+
+void KGVPart::slotConfigurationChanged()
+{
+    readSettings();
+    _psWidget->readSettings();
+    miniWidget()->redisplay();
 }
 
 void KGVPart::setDisplayOptions( const DisplayOptions& options )
