@@ -5,7 +5,7 @@
     copyright            : (C) 1999 by Klaas Freitag
     email                : freitag@suse.de
 
-    $Id: kookaview.cpp,v 1.73 2004/05/28 14:05:00 freitag Exp $
+    $Id: kookaview.cpp 364563 2004-11-20 17:27:51Z deller $
  ***************************************************************************/
 
 /***************************************************************************
@@ -29,6 +29,7 @@
 #include "kookaview.h"
 #include "resource.h"
 #include "kscandevice.h"
+#include "imgscaninfo.h"
 #include "devselector.h"
 #include "ksaneocr.h"
 #include "img_saver.h"
@@ -245,9 +246,9 @@ KookaView::KookaView( KParts::DockMainWindow *parent, const QCString& deviceToUs
    }
 
    /* New image created after scanning */
-   connect(sane, SIGNAL(sigNewImage(QImage*)), this, SLOT(slNewImageScanned(QImage*)));
+   connect(sane, SIGNAL(sigNewImage(QImage*,ImgScanInfo*)), this, SLOT(slNewImageScanned(QImage*,ImgScanInfo*)));
    /* New preview image */
-   connect(sane, SIGNAL(sigNewPreview(QImage*)), this, SLOT( slNewPreview(QImage*)));
+   connect(sane, SIGNAL(sigNewPreview(QImage*,ImgScanInfo *)), this, SLOT( slNewPreview(QImage*,ImgScanInfo *)));
 
    connect( sane, SIGNAL( sigScanStart() ), this, SLOT( slScanStart()));
    connect( sane, SIGNAL( sigScanFinished(KScanStat)), this, SLOT(slScanFinished(KScanStat)));
@@ -368,7 +369,7 @@ bool KookaView::slSelectDevice( const QCString& useDevice )
 	    /* load the preview image */
 	    if( preview_canvas )
 	    {
-	       preview_canvas->loadPreviewImage( selDevice );
+	       preview_canvas->setPreviewImage( sane->loadPreviewImage() );
 
                /* Call this after the devic is actually open */
                preview_canvas->slConnectScanner( sane );
@@ -478,26 +479,14 @@ void KookaView::print()
     }
 }
 
-void KookaView::slNewPreview( QImage *new_img )
+void KookaView::slNewPreview( QImage *new_img, ImgScanInfo * )
 {
    if( new_img )
    {
       if( ! new_img->isNull() )
       {
-	 ImgSaveStat is_stat = ISS_OK;
-	 ImgSaver img_saver( m_mainDock );
-
-	 is_stat = img_saver.savePreview( new_img, sane->shortScannerName() );
-
-	 if( is_stat != ISS_OK )
-	 {
-	    kdDebug(28000) << "ERROR in saving preview !" << endl;
-	 }
-	 else
-	 {
-	    /* flip preview to front */
-	    m_dockPreview->makeDockVisible();
-	 }
+	 /* flip preview to front */
+	 m_dockPreview->makeDockVisible();
       }
       preview_canvas->newImage( new_img );
    }
@@ -656,15 +645,10 @@ void KookaView::slAcquireStart( )
    }
 }
 
-void KookaView::slNewImageScanned( QImage* img )
+void KookaView::slNewImageScanned( QImage* img, ImgScanInfo* si )
 {
     KookaImageMeta *meta = new KookaImageMeta;
-
-    KScanOption res ( SANE_NAME_SCAN_RESOLUTION );
-    int resX;
-    res.get(&resX);
-    meta->setScanResolution(resX);
-
+    meta->setScanResolution(si->getXResolution(), si->getYResolution());
     packager->slAddImage(img, meta);
 }
 
