@@ -46,10 +46,14 @@
 #include <knuminput.h>
 #include <kiconloader.h>
 #include <kio/netaccess.h>
+#include <kio/job.h>
 #include <kpopupmenu.h>
+#include <kprocess.h>
+#include <kstandarddirs.h>
+#include <ktempfile.h>
+#include <ktrader.h>
 #include <kxmlguiclient.h>
 #include <kxmlguifactory.h>
-#include <ktrader.h>
 
 // local includes
 #include "xpdf/GlobalParams.h"
@@ -82,6 +86,9 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	: DCOPObject("kpdf"), KParts::ReadOnlyPart(parent, name), m_showMenuBarAction(0), m_showFullScreenAction(0),
 	m_actionsSearched(false), m_searchStarted(false)
 {
+	// connect the started signal to tell the job the mimetypes we like
+	connect(this, SIGNAL(started(KIO::Job *)), this, SLOT(setMimeTypes(KIO::Job *)));
+	
 	// load catalog for translation
 	KGlobal::locale()->insertCatalogue("kpdf");
 
@@ -102,7 +109,15 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_document = new KPDFDocument();
 	connect( m_document, SIGNAL( linkFind() ), this, SLOT( slotFind() ) );
 	connect( m_document, SIGNAL( linkGoToPage() ), this, SLOT( slotGoToPage() ) );
+	connect( m_document, SIGNAL( linkPresentation() ), this, SLOT( slotShowPresentation() ) );
+	connect( m_document, SIGNAL( linkEndPresentation() ), this, SLOT( slotHidePresentation() ) );
 	connect( m_document, SIGNAL( openURL(const KURL &) ), this, SLOT( openURLFromDocument(const KURL &) ) );
+	connect( m_document, SIGNAL( close() ), this, SLOT( close() ) );
+	
+	if (parent && parent->metaObject()->slotNames(true).contains("slotQuit()"))
+		connect( m_document, SIGNAL( quit() ), parent, SLOT( slotQuit() ) );
+	else
+		connect( m_document, SIGNAL( quit() ), this, SLOT( cannotQuit() ) );
 
 	// widgets: ^searchbar (toolbar containing label and SearchWidget)
 //	m_searchToolBar = new KToolBar( parentWidget, "searchBar" );
@@ -116,8 +131,11 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_splitter = new QSplitter( parentWidget, widgetName );
 	m_splitter->setOpaqueResize( true );
 	setWidget( m_splitter );
-	m_watchFile = new KToggleAction( i18n( "&Watch File" ), 0, this, SLOT( slotWatchFile() ), actionCollection(), "watch_file" );
-	m_watchFile->setChecked( KpdfSettings::watchFile() );
+	
+	m_showLeftPanel = new KToggleAction( i18n( "Show &Navigation Panel"), 0, this, SLOT( slotShowLeftPanel() ), actionCollection(), "show_leftpanel" );
+	m_showLeftPanel->setCheckedState( i18n( "Hide &Navigation Panel") );
+	m_showLeftPanel->setShortcut( "CTRL+L" );
+	m_showLeftPanel->setChecked( KpdfSettings::showLeftPanel() );
 
 	// widgets: [left panel] | []
 	m_leftPanel = new QWidget( m_splitter );
@@ -129,10 +147,12 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_toolBox = new QToolBox( m_leftPanel );
 	leftPanelLayout->addWidget( m_toolBox );
 
+	int index;
 	// [left toolbox: Table of Contents] | []
 	TOC * tocFrame = new TOC( m_toolBox, m_document );
 	connect(tocFrame, SIGNAL(hasTOC(bool)), this, SLOT(enableTOC(bool)));
-	m_toolBox->addItem( tocFrame, QIconSet(SmallIcon("text_left")), i18n("Contents") );
+	index = m_toolBox->addItem( tocFrame, QIconSet(SmallIcon("text_left")), i18n("Contents") );
+	m_toolBox->setItemToolTip(index, i18n("Contents"));
 	enableTOC( false );
 
 	// [left toolbox: Thumbnails and Bookmarks] | []
@@ -146,9 +166,12 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	thumbsBox->setStretchFactor( m_searchWidget, 100 );
 	thumbsBox->setStretchFactor( m_thumbnailList, 100 );
 //	thumbsBox->setStretchFactor( m_tc, 1 );
-	m_toolBox->addItem( thumbsBox, QIconSet(SmallIcon("thumbnail")), i18n("Thumbnails") );
+	index = m_toolBox->addItem( thumbsBox, QIconSet(SmallIcon("thumbnail")), i18n("Thumbnails") );
+	m_toolBox->setItemToolTip(index, i18n("Thumbnails"));
 	m_toolBox->setCurrentItem( thumbsBox );
 
+	slotShowLeftPanel();
+
 /*	// [left toolbox: Annotations] | []
 	QFrame * editFrame = new QFrame( m_toolBox );
 	int iIdx = m_toolBox->addItem( editFrame, QIconSet(SmallIcon("pencil")), i18n("Annotations") );
@@ -222,7 +245,7 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_saveAs = KStdAction::saveAs( this, SLOT( slotSaveFileAs() ), ac, "save" );
 	m_saveAs->setEnabled( false );
 	KAction * prefs = KStdAction::preferences( this, SLOT( slotPreferences() ), ac, "preferences" );
-	prefs->setText( i18n( "Configure PDF Viewer..." ) );
+	prefs->setText( i18n( "Configure KPDF..." ) );
 	m_printPreview = KStdAction::printPreview( this, SLOT( slotPrintPreview() ), ac );
 	m_printPreview->setEnabled( false );
 
@@ -247,13 +270,13 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	// get notified about splitter size changes (HACK that will be removed
 	// by connecting to Qt4::QSplitter's sliderMoved())
 	m_pageView->installEventFilter( this );
-	slotNewConfig();
-
 	m_watcher = new KDirWatch( this );
 	connect( m_watcher, SIGNAL( dirty( const QString& ) ), this, SLOT( slotFileDirty( const QString& ) ) );
 	m_dirtyHandler = new QTimer( this );
 	connect( m_dirtyHandler, SIGNAL( timeout() ),this, SLOT( slotDoFileDirty() ) );
 
+	slotNewConfig();
+
 	// [SPEECH] check for KTTSD presence and usability
 	KTrader::OfferList offers = KTrader::self()->query("DCOP/Text-to-Speech", "Name == 'KTTSD'");
 	KpdfSettings::setUseKTTSD( (offers.count() > 0) );
@@ -262,7 +285,6 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	// set our XML-UI resource file
 	setXMLFile("part.rc");
 	updateViewActions();
-	slotWatchFile();
 }
 
 Part::~Part()
@@ -300,6 +322,17 @@ uint Part::pages()
 	return m_document->pages();
 }
 
+uint Part::currentPage()
+{
+	if ( m_document->pages() == 0 ) return 0;
+	else return m_document->currentPage()+1;
+}
+
+KURL Part::currentDocument()
+{
+	return m_document->currentDocument();	
+}
+
 //this don't go anywhere but is required by genericfactory.h
 KAboutData* Part::createAboutData()
 {
@@ -322,11 +355,40 @@ bool Part::openFile()
     {
         mime = KMimeType::mimeType( m_bExtension->urlArgs().serviceType );
     }
+    if ( (*mime).is( "application/postscript" ) )
+    {
+        QString app = KStandardDirs::findExe( "ps2pdf" );
+        if ( !app.isNull() )
+        {
+            KTempFile tf( QString::null, ".pdf" );
+            if ( tf.status() == 0 )
+            {
+                tf.close();
+                m_temporaryLocalFile = tf.name();
+
+                KProcess *p = new KProcess;
+                *p << app;
+                *p << m_file << m_temporaryLocalFile;
+                m_pageView->showText(i18n("Converting from ps to pdf..."), 0);
+                connect(p, SIGNAL(processExited(KProcess *)), this, SLOT(psTransformEnded()));
+                p -> start();
+                return true;
+            }
+        }
+        else
+        {
+            KMessageBox::error(widget(), i18n("You do not have ps2pdf installed, so kpdf cannot open postscript files."));
+            return false;
+        }
+    }
+
+    m_temporaryLocalFile = QString::null;
+
     bool ok = m_document->openDocument( m_file, url(), mime );
 
     // update one-time actions
-    m_find->setEnabled( ok );
-    m_findNext->setEnabled( ok );
+    m_find->setEnabled( ok && m_document-> supportsSearching());
+    m_findNext->setEnabled( ok && m_document-> supportsSearching());
     m_saveAs->setEnabled( ok );
     m_printPreview->setEnabled( ok );
     m_showProperties->setEnabled( ok );
@@ -349,7 +411,10 @@ bool Part::openFile()
 
     // if the 'StartFullScreen' flag is set, start presentation
     if ( m_document->getMetaData( "StartFullScreen" ) == "yes" )
+    {
+	KMessageBox::information(m_presentationWidget, i18n("The document is going to be launched on presentation mode because the file requested it."), QString::null, "autoPresentationWarning");
         slotShowPresentation();
+    }
 
     return true;
 }
@@ -376,18 +441,35 @@ bool Part::openURL(const KURL &url)
     return b;
 }
 
+void Part::setMimeTypes(KIO::Job *job)
+{
+    if (job)
+    {
+        job->addMetaData("accept", "application/pdf, */*;q=0.5");
+    }
+}
+
 bool Part::closeURL()
 {
+    if (!m_temporaryLocalFile.isNull())
+    {
+        QFile::remove( m_temporaryLocalFile );
+        m_temporaryLocalFile = QString::null;
+    }
+
+    slotHidePresentation();
     m_find->setEnabled( false );
     m_findNext->setEnabled( false );
     m_saveAs->setEnabled( false );
     m_printPreview->setEnabled( false );
     m_showProperties->setEnabled( false );
     m_showPresentation->setEnabled( false );
-    updateViewActions();
+    emit setWindowCaption("");
+    emit enablePrintAction(false);
     m_searchStarted = false;
     if (!m_file.isEmpty()) m_watcher->removeFile(m_file);
     m_document->closeDocument();
+    updateViewActions();
     m_searchWidget->clearText();
     return KParts::ReadOnlyPart::closeURL();
 }
@@ -402,16 +484,15 @@ bool Part::eventFilter( QObject * watched, QEvent * e )
     return false;
 }
 
-void Part::slotWatchFile()
+void Part::slotShowLeftPanel()
 {
-  KpdfSettings::setWatchFile(m_watchFile->isChecked());
-  if( m_watchFile->isChecked() )
-    m_watcher->startScan();
-  else
-  {
-    m_dirtyHandler->stop();
-    m_watcher->stopScan();
-  }
+    bool showLeft = m_showLeftPanel->isChecked();
+    KpdfSettings::setShowLeftPanel(showLeft);
+    KpdfSettings::writeConfig();
+    // show/hide left qtoolbox
+    m_leftPanel->setShown( showLeft );
+    // this needs to be hidden explicitly to disable thumbnails gen
+    m_thumbnailList->setShown( showLeft );
 }
 
 void Part::slotFileDirty( const QString& fileName )
@@ -440,6 +521,7 @@ void Part::slotDoFileDirty()
     if (m_viewportDirty.pageNumber >= (int)m_document->pages()) m_viewportDirty.pageNumber = (int)m_document->pages() - 1;
     m_document->setViewport(m_viewportDirty);
     m_viewportDirty.pageNumber = -1;
+    emit enablePrintAction(true);
   }
   else
   {
@@ -448,6 +530,15 @@ void Part::slotDoFileDirty()
   }
 }
 
+void Part::close()
+{
+  if (parent() && strcmp(parent()->name(), "KPDF::Shell") == 0)
+  {
+    closeURL();
+  }
+  else KMessageBox::information(widget(), i18n("This link points to a close document action that does not work when using the embedded viewer."), QString::null, "warnNoCloseIfNotInKPDF");
+}
+
 void Part::updateViewActions()
 {
     bool opened = m_document->pages() > 0;
@@ -480,6 +571,17 @@ void Part::enableTOC(bool enable)
 	m_toolBox->setItemEnabled(0, enable);
 }
 
+void Part::psTransformEnded()
+{
+	m_file = m_temporaryLocalFile;
+	openFile();
+}
+
+void Part::cannotQuit()
+{
+	KMessageBox::information(widget(), i18n("This link points to a quit application action that does not work when using the embedded viewer."), QString::null, "warnNoQuitIfNotInKPDF");
+}
+
 void Part::saveSplitterSize()
 {
     KpdfSettings::setSplitterSizes( m_splitter->sizes() );
@@ -525,24 +627,26 @@ void Part::slotGoToPage()
 
 void Part::slotPreviousPage()
 {
-    if ( !m_document->currentPage() < 1 )
+    if ( m_document->isOpened() && !m_document->currentPage() < 1 )
         m_document->setViewportPage( m_document->currentPage() - 1 );
 }
 
 void Part::slotNextPage()
 {
-    if ( m_document->currentPage() < (m_document->pages() - 1) )
+    if ( m_document->isOpened() && m_document->currentPage() < (m_document->pages() - 1) )
         m_document->setViewportPage( m_document->currentPage() + 1 );
 }
 
 void Part::slotGotoFirst()
 {
-    m_document->setViewportPage( 0 );
+    if ( m_document->isOpened() )
+        m_document->setViewportPage( 0 );
 }
 
 void Part::slotGotoLast()
 {
-    m_document->setViewportPage( m_document->pages() - 1 );
+    if ( m_document->isOpened() )
+        m_document->setViewportPage( m_document->pages() - 1 );
 }
 
 void Part::slotHistoryBack()
@@ -588,7 +692,7 @@ void Part::slotSaveFileAs()
     {
         if ( KIO::NetAccess::exists( saveURL, false, widget() ) )
         {
-            if (KMessageBox::questionYesNo( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(saveURL.filename())) != KMessageBox::Yes)
+            if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(saveURL.filename()), QString::null, i18n("Overwrite")) != KMessageBox::Continue)
                 return;
         }
 
@@ -617,15 +721,16 @@ void Part::slotNewConfig()
     // Apply settings here. A good policy is to check wether the setting has
     // changed before applying changes.
 
-    // Left Panel and search Widget
-    bool showLeft = KpdfSettings::showLeftPanel();
-    if ( m_leftPanel->isShown() != showLeft )
+    // Watch File
+    bool watchFile = KpdfSettings::watchFile();  
+    if ( watchFile && m_watcher->isStopped() )
+        m_watcher->startScan();
+    if ( !watchFile && !m_watcher->isStopped() )
     {
-        // show/hide left qtoolbox
-        m_leftPanel->setShown( showLeft );
-        // this needs to be hidden explicitly to disable thumbnails gen
-        m_thumbnailList->setShown( showLeft );
+        m_dirtyHandler->stop();
+        m_watcher->stopScan();
     }
+
     bool showSearch = KpdfSettings::showSearchBar();
     if ( m_searchWidget->isShown() != showSearch )
         m_searchWidget->setShown( showSearch );
@@ -645,7 +750,7 @@ void Part::slotNewConfig()
     // update Main View and ThumbnailList contents
     // TODO do this only when changing KpdfSettings::renderMode()
     m_pageView->updateContents();
-    if ( showLeft && m_thumbnailList->isShown() )
+    if ( KpdfSettings::showLeftPanel() && m_thumbnailList->isShown() )
         m_thumbnailList->updateWidgets();
 }
 
@@ -770,10 +875,14 @@ void Part::slotShowProperties()
 
 void Part::slotShowPresentation()
 {
-    if ( m_presentationWidget )
-      delete (PresentationWidget*) m_presentationWidget;
+    if ( !m_presentationWidget )
+      m_presentationWidget = new PresentationWidget( widget(), m_document );
+}
 
-    m_presentationWidget = new PresentationWidget( m_document );
+void Part::slotHidePresentation()
+{
+    if ( m_presentationWidget )
+        delete (PresentationWidget*) m_presentationWidget;
 }
 
 void Part::slotPrint()
