@@ -57,6 +57,9 @@ PMShell::PMShell( const KURL& url )
    m_viewNumber = 0;
    m_objectsToDelete.setAutoDelete( true );
 
+   if (!initialGeometrySet())
+      resize(800,600);
+
    setupActions( );
 
    restoreOptions( );
@@ -408,13 +411,15 @@ void PMShell::slotFileOpen( )
 
 void PMShell::slotFileSave( )
 {
+	m_pPart->slotAboutToSave( );
+
    if( m_pPart->isModified( ) )
    {
       if( !m_pPart->url( ).isEmpty( ) &&
           m_pPart->isReadWrite( ) )
          m_pPart->saveAs( m_pPart->url( ) );
       else
-         slotFileSaveAs( );
+         saveAs( );
       setCaption( m_pPart->url( ).prettyURL( ) );
    }
    else
@@ -422,6 +427,12 @@ void PMShell::slotFileSave( )
 }
 
 void PMShell::slotFileSaveAs( )
+{
+	m_pPart->slotAboutToSave( );
+	saveAs( );
+}
+
+void PMShell::saveAs( )
 {
    KFileDialog dlg( QString::null,
                     QString( "*.kpm|" ) + i18n( "Povray Modeler Files (*.kpm)" ) +
@@ -638,9 +649,9 @@ bool PMShell::overwriteURL( const KURL& u )
       QString name( u.path( ) );
       info.setFile( name );
       if( info.exists( ) )
-         query = KMessageBox::warningYesNoCancel( 0, i18n( "A file with this name already exists.\nDo you want to overwrite it?" ) );
+         query = KMessageBox::warningContinueCancel( 0, i18n( "A file with this name already exists.\nDo you want to overwrite it?" ), QString::null, i18n("Overwrite") );
    }
-   return ( query == KMessageBox::Yes );
+   return ( query == KMessageBox::Continue );
 }
 
 void PMShell::slotSelectedLayout( int id )
