@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <stdlib.h>
@@ -143,6 +143,9 @@ void ImageWindow::setupActions()
     new KAction( i18n("Show Previous Image"), KStdAccel::prior(),
                  this, SLOT( slotRequestPrevious() ),
                  m_actions, "previous_image" );
+    new KAction( i18n("Delete Image"), Key_Delete,
+                 this, SLOT( imageDelete() ),
+                 m_actions, "delete_image" );
 
     new KAction( i18n("Zoom In"), Key_Plus,
                  this, SLOT( zoomIn() ),
@@ -215,12 +218,12 @@ void ImageWindow::setupActions()
     new KAction( i18n("Scroll Right"), Key_Right,
                  this, SLOT( scrollRight() ),
                  m_actions, "scroll_right" );
+    // --------
+    KAction *pause = new KAction( i18n("Pause Slideshow"), Key_P,
+				  this, SLOT( pauseSlideShow() ),
+				  m_actions, "kuick_slideshow_pause" );
 
-    KShortcut cut(Key_Return);
-    cut.append(KStdAccel::shortcut(KStdAccel::FullScreen));
-
-    KAction *action = KStdAction::fullScreen(this, SLOT( toggleFullscreen() ), m_actions, 0 );
-    action->setShortcut(cut);
+    KAction *fullscreenAction = KStdAction::fullScreen(this, SLOT( toggleFullscreen() ), m_actions, 0 );
 
     new KAction( i18n("Reload Image"), Key_Enter,
                  this, SLOT( reload() ),
@@ -231,6 +234,14 @@ void ImageWindow::setupActions()
                  m_actions, "properties" );
 
     m_actions->readShortcutSettings();
+
+    // Unfortunately there is no KAction::setShortcutDefault() :-/
+    // so add Key_Return as fullscreen shortcut _after_ readShortcutSettings()
+    KShortcut cut( fullscreenAction->shortcut() );
+    if ( cut == fullscreenAction->shortcutDefault() ) {
+	cut.append(KKey(Key_Return));
+	fullscreenAction->setShortcut(cut);
+    }
 }
 
 
@@ -389,6 +400,11 @@ void ImageWindow::reload()
     showNextImage( filename() );
 }
 
+void ImageWindow::pauseSlideShow()
+{
+    emit pauseSlideShowSignal();
+}
+
 void ImageWindow::addBrightness( int factor )
 {
     if ( factor == 0 )
@@ -488,6 +504,11 @@ void ImageWindow::lessGamma()
     addGamma( - kdata->gammaSteps );
 }
 
+void ImageWindow::imageDelete()
+{
+    emit deleteImage();
+}
+
 ///
 
 
@@ -521,6 +542,10 @@ void ImageWindow::keyPressEvent( QKeyEvent *e )
         close( true );
     else if ( KStdAccel::save().contains( KKey( e ) ) )
         saveImage();
+    else if ( key == Key_Right || key == Key_Down )
+        emit nextSlideRequested();
+    else if ( key == Key_Left || key == Key_Up )
+        emit prevSlideRequested(); // For future use...
 
     else {
         e->ignore();
@@ -817,6 +842,7 @@ void ImageWindow::setPopupMenu()
     viewerMenu->insertItem( i18n("Gamma"), gammaMenu );
     viewerMenu->insertSeparator();
 
+    m_actions->action("delete_image")->plug( viewerMenu );
     m_actions->action("print_image")->plug( viewerMenu );
     m_actions->action("save_image_as")->plug( viewerMenu );
     m_actions->action("properties")->plug( viewerMenu );
